@@ -8,13 +8,13 @@ from django.views.decorators.http import (
 from spine.utils import (
     JsonResponse,
     json,
-    LazyJSONDecode
 )
 from .models import (
     Example,
     ExampleMapper
 )
 
+
 def index(request):
     if request.method == 'GET':
         if request.is_ajax():
@@ -22,7 +22,8 @@ def index(request):
         else:
             return render_to_response("spineapp/app.html", RequestContext(request, {}))
     try:
-        data = json.loads(tuple(request.POST.dict())[0], cls=LazyJSONDecode)
+        data = json.loads(tuple(request.POST.dict())[0])
+        # data = json.loads(request.raw_post_data)
         data.pop("id")
         post = Example(**data)
         post.save()
