@@ -1,5 +1,6 @@
-# import warnings
-# warnings.simplefilter('ignore', Warning)
+import warnings
+warnings.simplefilter('ignore', Warning)
+
 
 from gencmd.tests.new import *
 from gencmd.tests.controller import *
@@ -7,4 +8,4 @@ from gencmd.tests.model import *
 from gencmd.tests.scaffold import *
 
 
-# vim: set et fenc=utf-8 ft=python ff=unix sts=4 sw=4 ts=4 :
+
